==> jc-1.4.0.tar.gz: gnu/xml/dom/DomXPathNSResolver.c <==
// class gnu.xml.dom.DomXPathNSResolver

// class file dependencies
// @dep_class bd5a917d4e832fc2 gnu_xml_dom_DomXPathNSResolver
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 2f4d9ed11c447a44 org_w3c_dom_Node
// @dep_class 5da5a7ba6048ab7c org_w3c_dom_xpath_XPathNSResolver

// header file dependencies
// @dep_header gnu_xml_dom_DomXPathNSResolver
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header org_w3c_dom_Node
// @dep_header org_w3c_dom_xpath_XPathNSResolver

#include "jc_defs.h"

#include "gnu/xml/dom/DomXPathNSResolver.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "org/w3c/dom/Node.h"
#include "org/w3c/dom/xpath/XPathNSResolver.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// org.w3c.dom.Node node
static _jc_field _jc_gnu_xml_dom_DomXPathNSResolver$field_info$node = {
	.name=		"node",
	.signature=	"Lorg/w3c/dom/Node;",
	.class=		&_jc_gnu_xml_dom_DomXPathNSResolver$type,
	.type=		&_jc_org_w3c_dom_Node$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_gnu_xml_dom_DomXPathNSResolver$object, refs[-1].gnu_xml_dom_DomXPathNSResolver.node),
};

// Fields
static _jc_field *const _jc_gnu_xml_dom_DomXPathNSResolver$fields[] = {
	&_jc_gnu_xml_dom_DomXPathNSResolver$field_info$node
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(org.w3c.dom.Node)
//

static _jc_linenum _jc_gnu_xml_dom_DomXPathNSResolver$linenum_table$_init$ea4cfa151ae11b7c[];

static const unsigned char _jc_gnu_xml_dom_DomXPathNSResolver$param_ptypes$_init$ea4cfa151ae11b7c[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_gnu_xml_dom_DomXPathNSResolver$param_types$_init$ea4cfa151ae11b7c[] = {
	&_jc_org_w3c_dom_Node$type
};

_jc_method _jc_gnu_xml_dom_DomXPathNSResolver$method_info$_init$ea4cfa151ae11b7c = {
	.name=			"<init>",
	.signature=		"(Lorg/w3c/dom/Node;)V",
	.class=			&_jc_gnu_xml_dom_DomXPathNSResolver$type,
	.param_types=		&_jc_gnu_xml_dom_DomXPathNSResolver$param_types$_init$ea4cfa151ae11b7c,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_xml_dom_DomXPathNSResolver$param_ptypes$_init$ea4cfa151ae11b7c,
	.signature_hash=	_JC_JLONG(0xea4cfa151ae11b7c),
	.access_flags=		0,
	.function=		&_jc_gnu_xml_dom_DomXPathNSResolver$method$_init$ea4cfa151ae11b7c,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_gnu_xml_dom_DomXPathNSResolver$linenum_table$_init$ea4cfa151ae11b7c
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_dom_DomXPathNSResolver, _init$ea4cfa151ae11b7c);

void
_jc_gnu_xml_dom_DomXPathNSResolver$method$_init$ea4cfa151ae11b7c(_jc_env *const env, _jc_gnu_xml_dom_DomXPathNSResolver$object *this, _jc_object *param0)
{
	struct _jc_gnu_xml_dom_DomXPathNSResolver$object *r0;
	struct _jc_object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(56);				// 0
	_JC_REF_FIELD(env, r0, gnu_xml_dom_DomXPathNSResolver, node) = r1;
	_JC_LINE_NUMBER(57);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String lookupNamespaceURI(java.lang.String)
//

static _jc_linenum _jc_gnu_xml_dom_DomXPathNSResolver$linenum_table$lookupNamespaceURI$14d569e8938f97a2[];

static const unsigned char _jc_gnu_xml_dom_DomXPathNSResolver$param_ptypes$lookupNamespaceURI$14d569e8938f97a2[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_gnu_xml_dom_DomXPathNSResolver$param_types$lookupNamespaceURI$14d569e8938f97a2[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_gnu_xml_dom_DomXPathNSResolver$method_info$lookupNamespaceURI$14d569e8938f97a2 = {
	.name=			"lookupNamespaceURI",
	.signature=		"(Ljava/lang/String;)Ljava/lang/String;",
	.class=			&_jc_gnu_xml_dom_DomXPathNSResolver$type,
	.param_types=		&_jc_gnu_xml_dom_DomXPathNSResolver$param_types$lookupNamespaceURI$14d569e8938f97a2,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_gnu_xml_dom_DomXPathNSResolver$param_ptypes$lookupNamespaceURI$14d569e8938f97a2,
	.signature_hash=	_JC_JLONG(0x14d569e8938f97a2),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_xml_dom_DomXPathNSResolver$method$lookupNamespaceURI$14d569e8938f97a2,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_xml_dom_DomXPathNSResolver$vtable, gnu_xml_dom_DomXPathNSResolver.lookupNamespaceURI$14d569e8938f97a2) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_xml_dom_DomXPathNSResolver$linenum_table$lookupNamespaceURI$14d569e8938f97a2
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_dom_DomXPathNSResolver, lookupNamespaceURI$14d569e8938f97a2);

_jc_java_lang_String$object *
_jc_gnu_xml_dom_DomXPathNSResolver$method$lookupNamespaceURI$14d569e8938f97a2(_jc_env *const env, _jc_gnu_xml_dom_DomXPathNSResolver$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_gnu_xml_dom_DomXPathNSResolver$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_object *r2;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(61);				// 0
	r2 = _JC_REF_FIELD(env, r0, gnu_xml_dom_DomXPathNSResolver, node);
	r1 = _JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0x14d569e8938f97a2), _jc_object *, r1);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_xml_dom_DomXPathNSResolver$methods[] = {
	&_jc_gnu_xml_dom_DomXPathNSResolver$method_info$_init$ea4cfa151ae11b7c,
	&_jc_gnu_xml_dom_DomXPathNSResolver$method_info$lookupNamespaceURI$14d569e8938f97a2
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_gnu_xml_dom_DomXPathNSResolver$interfaces[] = {
	&_jc_org_w3c_dom_xpath_XPathNSResolver$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_gnu_xml_dom_DomXPathNSResolver$imethod_hash_bucket_34[] = {
	&_jc_gnu_xml_dom_DomXPathNSResolver$method_info$lookupNamespaceURI$14d569e8938f97a2,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_gnu_xml_dom_DomXPathNSResolver$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[34]=	_jc_gnu_xml_dom_DomXPathNSResolver$imethod_hash_bucket_34
};

// Interface "quick" lookup hash table
static const void *_jc_gnu_xml_dom_DomXPathNSResolver$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[34]=	&_jc_gnu_xml_dom_DomXPathNSResolver$method$lookupNamespaceURI$14d569e8938f97a2
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_bucket_66[] = {
	&_jc_gnu_xml_dom_DomXPathNSResolver$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_bucket_124[] = {
	&_jc_org_w3c_dom_xpath_XPathNSResolver$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[66]=	_jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_bucket_66,
	[113]=	_jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_bucket_113,
	[124]=	_jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_bucket_124
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_xml_dom_DomXPathNSResolver$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "org/w3c/dom/Node",	_JC_JLONG(0x2f4d9ed11c447a44) },
	{ "org/w3c/dom/xpath/XPathNSResolver",	_JC_JLONG(0x5da5a7ba6048ab7c) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_xml_dom_DomXPathNSResolver$vtype _jc_gnu_xml_dom_DomXPathNSResolver$type = {
    .type= {
	.name=			"gnu/xml/dom/DomXPathNSResolver",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_gnu_xml_dom_DomXPathNSResolver$interfaces) / sizeof(*_jc_gnu_xml_dom_DomXPathNSResolver$interfaces),
	.interfaces=		_jc_gnu_xml_dom_DomXPathNSResolver$interfaces,
	.imethod_hash_table=	_jc_gnu_xml_dom_DomXPathNSResolver$imethod_hash_table,
	.imethod_quick_table=	_jc_gnu_xml_dom_DomXPathNSResolver$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xbd5a917d4e832fc2),
		.source_file=		"DomXPathNSResolver.java",
		.instance_size=		sizeof(_jc_gnu_xml_dom_DomXPathNSResolver$refs) + sizeof(_jc_gnu_xml_dom_DomXPathNSResolver$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_gnu_xml_dom_DomXPathNSResolver$fields) / sizeof(*_jc_gnu_xml_dom_DomXPathNSResolver$fields),
		.fields=		_jc_gnu_xml_dom_DomXPathNSResolver$fields,
		.num_methods=		sizeof(_jc_gnu_xml_dom_DomXPathNSResolver$methods) / sizeof(*_jc_gnu_xml_dom_DomXPathNSResolver$methods),
		.methods=		_jc_gnu_xml_dom_DomXPathNSResolver$methods,
		.instanceof_hash_table=	_jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_xml_dom_DomXPathNSResolver$class_depends) / sizeof(*_jc_gnu_xml_dom_DomXPathNSResolver$class_depends),
		.class_depends=		_jc_gnu_xml_dom_DomXPathNSResolver$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_xml_dom_DomXPathNSResolver= {
	    .lookupNamespaceURI$14d569e8938f97a2=
		&_jc_gnu_xml_dom_DomXPathNSResolver$method$lookupNamespaceURI$14d569e8938f97a2,
	},
    }
};

==> jc-1.4.5.tar.gz: gnu/xml/dom/DomXPathNSResolver.c <==
// class gnu.xml.dom.DomXPathNSResolver

// class file dependencies
// @dep_class bd5a917d4e832fc2 gnu_xml_dom_DomXPathNSResolver
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 2f4d9ed11c447a44 org_w3c_dom_Node
// @dep_class 5da5a7ba6048ab7c org_w3c_dom_xpath_XPathNSResolver

// header file dependencies
// @dep_header gnu_xml_dom_DomXPathNSResolver
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header org_w3c_dom_Node
// @dep_header org_w3c_dom_xpath_XPathNSResolver

#include "jc_defs.h"

#include "gnu/xml/dom/DomXPathNSResolver.h"
#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "org/w3c/dom/Node.h"
#include "org/w3c/dom/xpath/XPathNSResolver.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// org.w3c.dom.Node node
static _jc_field _jc_gnu_xml_dom_DomXPathNSResolver$field_info$node = {
	.name=		"node",
	.signature=	"Lorg/w3c/dom/Node;",
	.class=		&_jc_gnu_xml_dom_DomXPathNSResolver$type,
	.type=		&_jc_org_w3c_dom_Node$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_gnu_xml_dom_DomXPathNSResolver$object, refs[-1].gnu_xml_dom_DomXPathNSResolver.node),
};

// Fields
static _jc_field *const _jc_gnu_xml_dom_DomXPathNSResolver$fields[] = {
	&_jc_gnu_xml_dom_DomXPathNSResolver$field_info$node
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(org.w3c.dom.Node)
//

static _jc_linenum _jc_gnu_xml_dom_DomXPathNSResolver$linenum_table$_init$ea4cfa151ae11b7c[];

static const unsigned char _jc_gnu_xml_dom_DomXPathNSResolver$param_ptypes$_init$ea4cfa151ae11b7c[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_gnu_xml_dom_DomXPathNSResolver$param_types$_init$ea4cfa151ae11b7c[] = {
	&_jc_org_w3c_dom_Node$type
};

_jc_method _jc_gnu_xml_dom_DomXPathNSResolver$method_info$_init$ea4cfa151ae11b7c = {
	.name=			"<init>",
	.signature=		"(Lorg/w3c/dom/Node;)V",
	.class=			&_jc_gnu_xml_dom_DomXPathNSResolver$type,
	.param_types=		&_jc_gnu_xml_dom_DomXPathNSResolver$param_types$_init$ea4cfa151ae11b7c,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_gnu_xml_dom_DomXPathNSResolver$param_ptypes$_init$ea4cfa151ae11b7c,
	.signature_hash=	_JC_JLONG(0xea4cfa151ae11b7c),
	.access_flags=		0,
	.function=		&_jc_gnu_xml_dom_DomXPathNSResolver$method$_init$ea4cfa151ae11b7c,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	2,
	      .table=	_jc_gnu_xml_dom_DomXPathNSResolver$linenum_table$_init$ea4cfa151ae11b7c
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_dom_DomXPathNSResolver, _init$ea4cfa151ae11b7c);

void _JC_JCNI_ATTR
_jc_gnu_xml_dom_DomXPathNSResolver$method$_init$ea4cfa151ae11b7c(_jc_env *const env, _jc_gnu_xml_dom_DomXPathNSResolver$object *this, _jc_object *param0)
{
	struct _jc_gnu_xml_dom_DomXPathNSResolver$object *r0;
	struct _jc_object *r1;

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(56);				// 0
	_JC_REF_FIELD(env, r0, gnu_xml_dom_DomXPathNSResolver, node) = r1;
	_JC_LINE_NUMBER(57);				// 1
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String lookupNamespaceURI(java.lang.String)
//

static _jc_linenum _jc_gnu_xml_dom_DomXPathNSResolver$linenum_table$lookupNamespaceURI$14d569e8938f97a2[];

static const unsigned char _jc_gnu_xml_dom_DomXPathNSResolver$param_ptypes$lookupNamespaceURI$14d569e8938f97a2[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_gnu_xml_dom_DomXPathNSResolver$param_types$lookupNamespaceURI$14d569e8938f97a2[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_gnu_xml_dom_DomXPathNSResolver$method_info$lookupNamespaceURI$14d569e8938f97a2 = {
	.name=			"lookupNamespaceURI",
	.signature=		"(Ljava/lang/String;)Ljava/lang/String;",
	.class=			&_jc_gnu_xml_dom_DomXPathNSResolver$type,
	.param_types=		&_jc_gnu_xml_dom_DomXPathNSResolver$param_types$lookupNamespaceURI$14d569e8938f97a2,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_gnu_xml_dom_DomXPathNSResolver$param_ptypes$lookupNamespaceURI$14d569e8938f97a2,
	.signature_hash=	_JC_JLONG(0x14d569e8938f97a2),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_gnu_xml_dom_DomXPathNSResolver$method$lookupNamespaceURI$14d569e8938f97a2,
	.vtable_index=		_JC_OFFSETOF(struct _jc_gnu_xml_dom_DomXPathNSResolver$vtable, gnu_xml_dom_DomXPathNSResolver.lookupNamespaceURI$14d569e8938f97a2) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_gnu_xml_dom_DomXPathNSResolver$linenum_table$lookupNamespaceURI$14d569e8938f97a2
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(gnu_xml_dom_DomXPathNSResolver, lookupNamespaceURI$14d569e8938f97a2);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_gnu_xml_dom_DomXPathNSResolver$method$lookupNamespaceURI$14d569e8938f97a2(_jc_env *const env, _jc_gnu_xml_dom_DomXPathNSResolver$object *this, _jc_java_lang_String$object *param0)
{
	struct _jc_gnu_xml_dom_DomXPathNSResolver$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_object *r2;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	_JC_LINE_NUMBER(61);				// 0
	r2 = _JC_REF_FIELD(env, r0, gnu_xml_dom_DomXPathNSResolver, node);
	r1 = _JC_INVOKE_INTERFACE(env, r2, _JC_JLONG(0x14d569e8938f97a2), _jc_object *, (_jc_env *, struct _jc_object *, struct _jc_java_lang_String$object *), r1);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_gnu_xml_dom_DomXPathNSResolver$methods[] = {
	&_jc_gnu_xml_dom_DomXPathNSResolver$method_info$_init$ea4cfa151ae11b7c,
	&_jc_gnu_xml_dom_DomXPathNSResolver$method_info$lookupNamespaceURI$14d569e8938f97a2
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_gnu_xml_dom_DomXPathNSResolver$interfaces[] = {
	&_jc_org_w3c_dom_xpath_XPathNSResolver$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_gnu_xml_dom_DomXPathNSResolver$imethod_hash_bucket_34[] = {
	&_jc_gnu_xml_dom_DomXPathNSResolver$method_info$lookupNamespaceURI$14d569e8938f97a2,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_gnu_xml_dom_DomXPathNSResolver$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[34]=	_jc_gnu_xml_dom_DomXPathNSResolver$imethod_hash_bucket_34
};

// Interface "quick" lookup hash table
static const void *_jc_gnu_xml_dom_DomXPathNSResolver$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[34]=	&_jc_gnu_xml_dom_DomXPathNSResolver$method$lookupNamespaceURI$14d569e8938f97a2
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_bucket_66[] = {
	&_jc_gnu_xml_dom_DomXPathNSResolver$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};
static _jc_type *const _jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_bucket_124[] = {
	&_jc_org_w3c_dom_xpath_XPathNSResolver$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[66]=	_jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_bucket_66,
	[101]=	_jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_bucket_101,
	[124]=	_jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_bucket_124
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_gnu_xml_dom_DomXPathNSResolver$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "org/w3c/dom/Node",	_JC_JLONG(0x2f4d9ed11c447a44) },
	{ "org/w3c/dom/xpath/XPathNSResolver",	_JC_JLONG(0x5da5a7ba6048ab7c) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_gnu_xml_dom_DomXPathNSResolver$vtype _jc_gnu_xml_dom_DomXPathNSResolver$type = {
    .type= {
	.name=			"gnu/xml/dom/DomXPathNSResolver",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		0,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_gnu_xml_dom_DomXPathNSResolver$interfaces) / sizeof(*_jc_gnu_xml_dom_DomXPathNSResolver$interfaces),
	.interfaces=		_jc_gnu_xml_dom_DomXPathNSResolver$interfaces,
	.imethod_hash_table=	_jc_gnu_xml_dom_DomXPathNSResolver$imethod_hash_table,
	.imethod_quick_table=	_jc_gnu_xml_dom_DomXPathNSResolver$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0xbd5a917d4e832fc2),
		.source_file=		"DomXPathNSResolver.java",
		.instance_size=		sizeof(_jc_gnu_xml_dom_DomXPathNSResolver$refs) + sizeof(_jc_gnu_xml_dom_DomXPathNSResolver$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_gnu_xml_dom_DomXPathNSResolver$fields) / sizeof(*_jc_gnu_xml_dom_DomXPathNSResolver$fields),
		.fields=		_jc_gnu_xml_dom_DomXPathNSResolver$fields,
		.num_methods=		sizeof(_jc_gnu_xml_dom_DomXPathNSResolver$methods) / sizeof(*_jc_gnu_xml_dom_DomXPathNSResolver$methods),
		.methods=		_jc_gnu_xml_dom_DomXPathNSResolver$methods,
		.instanceof_hash_table=	_jc_gnu_xml_dom_DomXPathNSResolver$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_gnu_xml_dom_DomXPathNSResolver$class_depends) / sizeof(*_jc_gnu_xml_dom_DomXPathNSResolver$class_depends),
		.class_depends=		_jc_gnu_xml_dom_DomXPathNSResolver$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.gnu_xml_dom_DomXPathNSResolver= {
	    .lookupNamespaceURI$14d569e8938f97a2=
		&_jc_gnu_xml_dom_DomXPathNSResolver$method$lookupNamespaceURI$14d569e8938f97a2,
	},
    }
};
